==> jc-1.4.0.tar.gz: java/security/GeneralSecurityException.h <==
// public class java.security.GeneralSecurityException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 692089051f4c8d0b java_security_GeneralSecurityException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_security_GeneralSecurityException_H_
#define _JC_java_security_GeneralSecurityException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_GeneralSecurityException$sub_refs	_jc_java_security_GeneralSecurityException$sub_refs;
typedef struct _jc_java_security_GeneralSecurityException$sub_nonrefs	_jc_java_security_GeneralSecurityException$sub_nonrefs;
typedef struct _jc_java_security_GeneralSecurityException$refs	_jc_java_security_GeneralSecurityException$refs;
typedef struct _jc_java_security_GeneralSecurityException$nonrefs	_jc_java_security_GeneralSecurityException$nonrefs;
typedef struct _jc_java_security_GeneralSecurityException$object	_jc_java_security_GeneralSecurityException$object;

typedef struct _jc_java_security_GeneralSecurityException$fields_struct	_jc_java_security_GeneralSecurityException$fields_struct;
typedef const struct _jc_java_security_GeneralSecurityException$vmethods	_jc_java_security_GeneralSecurityException$vmethods;
typedef const struct _jc_java_security_GeneralSecurityException$vtable	_jc_java_security_GeneralSecurityException$vtable;
typedef const struct _jc_java_security_GeneralSecurityException$vtype	_jc_java_security_GeneralSecurityException$vtype;

// Class fields structure
struct _jc_java_security_GeneralSecurityException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_GeneralSecurityException$fields_struct _jc_java_security_GeneralSecurityException$class_fields;

// Constructors
extern void _jc_java_security_GeneralSecurityException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_GeneralSecurityException$object *);
extern void _jc_java_security_GeneralSecurityException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_GeneralSecurityException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_security_GeneralSecurityException$vmethods {
};

// Vtable
struct _jc_java_security_GeneralSecurityException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_GeneralSecurityException$vmethods	java_security_GeneralSecurityException;
};

// Vtype
struct _jc_java_security_GeneralSecurityException$vtype {
	_jc_type			type;
	_jc_java_security_GeneralSecurityException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_GeneralSecurityException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_GeneralSecurityException$refs {
    _jc_java_security_GeneralSecurityException$sub_refs	java_security_GeneralSecurityException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_GeneralSecurityException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_GeneralSecurityException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_GeneralSecurityException$sub_nonrefs	java_security_GeneralSecurityException;
};

// Object instance structure
struct _jc_java_security_GeneralSecurityException$object {
	_jc_java_security_GeneralSecurityException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_GeneralSecurityException$vtype	*vtype;
	_jc_java_security_GeneralSecurityException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_GeneralSecurityException$vtype _jc_java_security_GeneralSecurityException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_GeneralSecurityException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_GeneralSecurityException$class_object;

#endif	/* _JC_java_security_GeneralSecurityException_H_ */

==> jc-1.4.6.tar.gz: java/security/GeneralSecurityException.h <==
// public class java.security.GeneralSecurityException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 692089051f4c8d0b java_security_GeneralSecurityException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_security_GeneralSecurityException_H_
#define _JC_java_security_GeneralSecurityException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_GeneralSecurityException$sub_refs	_jc_java_security_GeneralSecurityException$sub_refs;
typedef struct _jc_java_security_GeneralSecurityException$sub_nonrefs	_jc_java_security_GeneralSecurityException$sub_nonrefs;
typedef struct _jc_java_security_GeneralSecurityException$refs	_jc_java_security_GeneralSecurityException$refs;
typedef struct _jc_java_security_GeneralSecurityException$nonrefs	_jc_java_security_GeneralSecurityException$nonrefs;
typedef struct _jc_java_security_GeneralSecurityException$object	_jc_java_security_GeneralSecurityException$object;

typedef struct _jc_java_security_GeneralSecurityException$fields_struct	_jc_java_security_GeneralSecurityException$fields_struct;
typedef const struct _jc_java_security_GeneralSecurityException$vmethods	_jc_java_security_GeneralSecurityException$vmethods;
typedef const struct _jc_java_security_GeneralSecurityException$vtable	_jc_java_security_GeneralSecurityException$vtable;
typedef const struct _jc_java_security_GeneralSecurityException$vtype	_jc_java_security_GeneralSecurityException$vtype;

// Class fields structure
struct _jc_java_security_GeneralSecurityException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_GeneralSecurityException$fields_struct _jc_java_security_GeneralSecurityException$class_fields;

// Constructors
extern void _jc_java_security_GeneralSecurityException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_GeneralSecurityException$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_GeneralSecurityException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_GeneralSecurityException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_security_GeneralSecurityException$vmethods {
};

// Vtable
struct _jc_java_security_GeneralSecurityException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_GeneralSecurityException$vmethods	java_security_GeneralSecurityException;
};

// Vtype
struct _jc_java_security_GeneralSecurityException$vtype {
	_jc_type			type;
	_jc_java_security_GeneralSecurityException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_GeneralSecurityException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_GeneralSecurityException$refs {
    _jc_java_security_GeneralSecurityException$sub_refs	java_security_GeneralSecurityException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_GeneralSecurityException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_GeneralSecurityException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_GeneralSecurityException$sub_nonrefs	java_security_GeneralSecurityException;
};

// Object instance structure
struct _jc_java_security_GeneralSecurityException$object {
	_jc_java_security_GeneralSecurityException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_GeneralSecurityException$vtype	*vtype;
	_jc_java_security_GeneralSecurityException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_GeneralSecurityException$vtype _jc_java_security_GeneralSecurityException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_GeneralSecurityException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_GeneralSecurityException$class_object;

#endif	/* _JC_java_security_GeneralSecurityException_H_ */
